'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadLanguage = loadLanguage;
exports.registerLanguage = registerLanguage;
exports.registerAllAvailableLanguages = registerAllAvailableLanguages;

var _monacoEditor = require('monaco-editor');

var monaco = _interopRequireWildcard(_monacoEditor);

var _languages = require('./languages');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

var languagePromises = {};

function loadLanguage(languageId) {
  if (languagePromises[languageId]) {
    return languagePromises[languageId];
  }

  return import('./ace/definitions/' + languageId).then(function (_ref) {
    var HighlightRules = _ref.default;

    var rules = new HighlightRules();
    return (0, _languages.registerRulesForLanguage)(languageId, rules);
  });
}

function registerLanguage(languageId) {
  monaco.languages.register({
    id: languageId
  });

  monaco.languages.onLanguage(languageId, function () {
    loadLanguage(languageId);
  });
}

function registerAllAvailableLanguages() {
  _languages.AVAILABLE_LANGUAGES.forEach(function (langId) {
    return registerLanguage(langId);
  });
}